==> cobweb-launcher-0.0.2.tar.gz: cobweb-launcher-0.0.2/cobweb/db/storer/loghub.py <==
import json
from base.log import log
from base.interface import StorerInterface
from aliyun.log import LogClient, LogItem, PutLogsRequest


class Loghub(StorerInterface):

    def __init__(self, table, fields, length, queue, config):
        super().__init__(table, fields, length, queue, config)
        self.client = None

    def init_loghub_clint(self):
        try:
            self.client = LogClient(
                self.config['endpoint'],
                self.config['access_key_id'],
                self.config['access_key']
            )
        except Exception as e:
            self.client = None
            return False

    def store(self, data_list):
        try:
            if not self.client:
                self.init_loghub_clint()

            log_items = list()
            for item in data_list:
                temp = item._asdict()
                for key, value in temp.items():
                    if isinstance(value, str):
                        temp[key] = value
                    else:
                        temp[key] = json.dumps(value, ensure_ascii=False)
                log_item = LogItem()
                contents = sorted(temp.items())  # dict to tuple
                log_item.set_contents(contents)
                log_items.append(log_item)
            request = PutLogsRequest(
                project=self.config["project"],
                logstore=self.table,
                topic=self.config["topic"],
                source=self.config.get("source"),
                logitems=log_items,
                compress=True
            )
            self.client.put_logs(request=request)
            log.info(f"save data, data length: {len(data_list)}")
            return True
        except Exception as e:
            log.exception(e)
            return False

==> cobweb-launcher-0.0.5.tar.gz: cobweb-launcher-0.0.5/cobweb/db/storer/loghub.py <==
import json
from aliyun.log import LogClient, LogItem, PutLogsRequest
from cobweb import log, StorerInterface


class Loghub(StorerInterface):

    def __init__(self, table, length, queue, config):
        super().__init__(table, length, queue, config)
        self.client = None

    def init_loghub_clint(self):
        try:
            self.client = LogClient(
                self.config['endpoint'],
                self.config['access_key_id'],
                self.config['access_key']
            )
        except Exception as e:
            self.client = None
            return False

    def store(self, data_list):
        try:
            if not self.client:
                self.init_loghub_clint()

            log_items = list()
            for item in data_list:
                temp = item._asdict()
                for key, value in temp.items():
                    if isinstance(value, str):
                        temp[key] = value
                    else:
                        temp[key] = json.dumps(value, ensure_ascii=False)
                log_item = LogItem()
                contents = sorted(temp.items())  # dict to tuple
                log_item.set_contents(contents)
                log_items.append(log_item)
            request = PutLogsRequest(
                project=self.config["project"],
                logstore=self.table,
                topic=self.config["topic"],
                source=self.config.get("source"),
                logitems=log_items,
                compress=True
            )
            self.client.put_logs(request=request)
            log.info(f"save data, data length: {len(data_list)}")
            return True
        except Exception as e:
            log.exception(e)
            return False
